/********************************************************************************
*                                                                               *
*                                 Create ArrowButton              *
*                                                                               *
*********************************************************************************
* Copyright (C) 2001 by Anastasios Sarris.   All Rights Reserved.             *
*********************************************************************************/
#include "/usr/local/include/fox/fx.h"
#include "ArrowDialog.h"
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "icons.h"
#include "vars.h"

/*******************************************************************************/
// Map
FXDEFMAP(ArrowDialog) ArrowDialogMap[]={
  FXMAPFUNC(SEL_COMMAND,ArrowDialog::ID_NAME,ArrowDialog::onCmdName),
  FXMAPFUNC(SEL_COMMAND,ArrowDialog::ID_WIDTH,ArrowDialog::onCmdWidth),
  FXMAPFUNC(SEL_COMMAND,ArrowDialog::ID_HEIGHT,ArrowDialog::onCmdHeight),
  FXMAPFUNC(SEL_COMMAND,ArrowDialog::ID_POSX,ArrowDialog::onCmdPosX),
  FXMAPFUNC(SEL_COMMAND,ArrowDialog::ID_POSY,ArrowDialog::onCmdPosY),
  FXMAPFUNC(SEL_COMMAND,ArrowDialog::ID_RESULTS,ArrowDialog::onCmdResults),
  FXMAPFUNC(SEL_COMMAND,ArrowDialog::ID_ALIGN,ArrowDialog::onCmdAlign),
  FXMAPFUNC(SEL_COMMAND,ArrowDialog::ID_LAYOUT,ArrowDialog::onCmdLayout),
  FXMAPFUNC(SEL_COMMAND,ArrowDialog::ID_TARGET,ArrowDialog::onCmdTarget),
  FXMAPFUNC(SEL_COMMAND,ArrowDialog::ID_FRAME,ArrowDialog::onCmdFrame),
  FXMAPFUNC(SEL_COMMAND,ArrowDialog::ID_ARROW_DIR,ArrowDialog::onCmdArrowDir),
  FXMAPFUNC(SEL_COMMAND,ArrowDialog::ID_ARROW_COLOR,ArrowDialog::onCmdArrowColor),
  FXMAPFUNC(SEL_COMMAND,ArrowDialog::ID_DECLARE,ArrowDialog::onCmdDeclare),
  FXMAPFUNC(SEL_COMMAND,ArrowDialog::ID_BASE_COLOR,ArrowDialog::onCmdBaseColor),
  FXMAPFUNC(SEL_COMMAND,ArrowDialog::ID_BORDER_COLOR,ArrowDialog::onCmdBorderColor),
  FXMAPFUNC(SEL_COMMAND,ArrowDialog::ID_HILITE_COLOR,ArrowDialog::onCmdHiliteColor),
  FXMAPFUNC(SEL_COMMAND,ArrowDialog::ID_SHADOW_COLOR,ArrowDialog::onCmdShadowColor),
  FXMAPFUNC(SEL_COMMAND,ArrowDialog::ID_BACK_COLOR,ArrowDialog::onCmdBackColor),
  FXMAPFUNC(SEL_COMMAND,ArrowDialog::ID_COLOR_DECLARE,ArrowDialog::onCmdColorDeclare),
  FXMAPFUNC(SEL_COMMAND,ArrowDialog::ID_SELECTOR,ArrowDialog::onCmdSelector),
};


// ButtonApp implementation
FXIMPLEMENT(ArrowDialog,FXDialogBox,ArrowDialogMap,ARRAYNUMBER(ArrowDialogMap))

// Make some windows
ArrowDialog::ArrowDialog(FXWindow* owner):FXDialogBox(owner,"Arrow Button Creator",DECOR_TITLE|DECOR_BORDER,0)
{
  mainFont=new FXFont(getApp(),AppFont,10,FONTWEIGHT_NORMAL,FONTSLANT_REGULAR,FONTENCODING_GREEK);
  buttons=new FXHorizontalFrame(this,LAYOUT_SIDE_BOTTOM|FRAME_NONE|LAYOUT_FILL_X|PACK_UNIFORM_WIDTH,0,0,0,0,40,40,20,20);
  FXMatrix* BasicControls=new FXMatrix(this,1,FRAME_NONE|MATRIX_BY_COLUMNS|LAYOUT_FILL_X);
  FXToolbarShell* dragshell2=new FXToolbarShell(this,FRAME_RAISED|FRAME_THICK);
  mdiTools=new FXToolbar(BasicControls,dragshell2,LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  new FXToolbarGrip(mdiTools,this,ID_TOOLBARGRIP);

  //Basic Color
  btnBaseColor=new FXButton(mdiTools,"BS\tBase color",coloricon,this,ID_BASE_COLOR,BUTTON_TOOLBAR|ICON_UNDER_TEXT|JUSTIFY_NORMAL|LAYOUT_NORMAL|FRAME_RAISED,50,55,35,35);
  btnBaseColor->setFont(mainFont);
  btnBaseColor->setTextColor(FXRGBA(0,0,200,255));	
  		
  //HIlite Color
  btnHiliteColor=new FXButton(mdiTools,"HT\tHilite color",coloricon,this,ID_HILITE_COLOR,BUTTON_TOOLBAR|ICON_UNDER_TEXT|JUSTIFY_NORMAL|LAYOUT_NORMAL|FRAME_RAISED,50,55,35,35);
  btnHiliteColor->setFont(mainFont);
  btnHiliteColor->setTextColor(FXRGBA(0,0,255,255));

  //ArrowColor
  FXButton* btnArrowColor=new FXButton(mdiTools,"AC\tArrow color",coloricon,this,ID_ARROW_COLOR,BUTTON_TOOLBAR|ICON_UNDER_TEXT|JUSTIFY_NORMAL|LAYOUT_NORMAL|FRAME_RAISED,50,55,35,35);
  btnArrowColor->setFont(mainFont);
  btnArrowColor->setTextColor(FXRGBA(0,0,255,255));
		
  //Border Color
  btnBorderColor=new FXButton(mdiTools,"Bd\tBorder color",coloricon,this,ID_BORDER_COLOR,BUTTON_TOOLBAR|ICON_UNDER_TEXT|JUSTIFY_NORMAL|LAYOUT_NORMAL|FRAME_RAISED,50,55,35,35);
  btnBorderColor->setFont(mainFont);
  btnBorderColor->setTextColor(FXRGBA(0,0,255,255));

  //Shadow Color
  btnShadowColor=new FXButton(mdiTools,"Sd\tShadow color",coloricon,this,ID_SHADOW_COLOR,BUTTON_TOOLBAR|ICON_UNDER_TEXT|JUSTIFY_NORMAL|LAYOUT_NORMAL|FRAME_RAISED,50,55,35,35);
  btnShadowColor->setFont(mainFont);
  btnShadowColor->setTextColor(FXRGBA(0,0,255,255));

  //BackColor
  btnBackColor=new FXButton(mdiTools,"Bc\tBack color",coloricon,this,ID_BACK_COLOR,BUTTON_TOOLBAR|ICON_UNDER_TEXT|JUSTIFY_NORMAL|LAYOUT_NORMAL|FRAME_RAISED,50,55,35,35);
  btnBackColor->setFont(mainFont);
  btnBackColor->setTextColor(FXRGBA(0,0,255,255));
	
  FXMatrix* controls=new FXMatrix(BasicControls,2,FRAME_RIDGE|MATRIX_BY_COLUMNS|LAYOUT_FILL_X);		

  // Name
  FXLabel *lblName=new FXLabel(controls,"&Name:\tObject name",NULL,LAYOUT_FILL_ROW|JUSTIFY_LEFT);
  lblName->setFont(mainFont);
  txtName=new FXTextField(controls,15,this,ID_NAME,LAYOUT_LEFT|FRAME_SUNKEN);
  txtName->setFont(mainFont);
  txtName->setText("arbtn");
	
   //Owner
  FXLabel *lblOwner=new FXLabel(controls,"&Owner:\tObject Owner",NULL,LAYOUT_FILL_ROW|JUSTIFY_LEFT);
  lblOwner->setFont(mainFont);
  txtOwner=new FXTextField(controls,15,this,ID_OWNER,LAYOUT_LEFT|FRAME_SUNKEN);
  txtOwner->setFont(mainFont);

  //Target
  FXLabel *lblTarget=new FXLabel(controls,"&Target,ID:\tTarget,ID",NULL,LAYOUT_FILL_ROW|JUSTIFY_LEFT);
  lblTarget->setFont(mainFont);
  txtTarget=new FXTextField(controls,15,this,ID_TARGET,LAYOUT_LEFT|FRAME_SUNKEN);
  txtTarget->setFont(mainFont);

  //Selector
  FXLabel *lblSelector=new FXLabel(controls,"&ID:",NULL,LAYOUT_FILL_ROW|JUSTIFY_LEFT);
  lblSelector->setFont(mainFont);
  txtSelector=new FXTextField(controls,15,this,ID_SELECTOR,LAYOUT_LEFT|FRAME_SUNKEN);
  txtSelector->setFont(mainFont);

  //Arrow Direction
  FXLabel *lbldir=new FXLabel(controls,"&Arrow Direction:",NULL,LAYOUT_LEFT|JUSTIFY_LEFT);
  lbldir->setFont(mainFont);
  arrowdirection=new FXComboBox(controls,15,5,this,ID_ARROW_DIR,COMBOBOX_INSERT_LAST|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP);
  for(int i=0; i<4; i++){  arrowdirection->appendItem(dirArrow[i]);         }
  arrowdirection->setCurrentItem(0);
	
  //Alignment
  FXLabel *lblalign=new FXLabel(controls,"&Alignment:",NULL,LAYOUT_LEFT|JUSTIFY_LEFT);
  lblalign->setFont(mainFont);
  comboalign=new FXComboBox(controls,15,5,this,ID_ALIGN,COMBOBOX_INSERT_LAST|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP);
  for(int i=0; i<8; i++){  comboalign->appendItem(stralign[i]);         }
  comboalign->setCurrentItem(0);
	
  //Layout
  FXLabel *lbllayout=new FXLabel(controls,"&Layout:",NULL,LAYOUT_LEFT|JUSTIFY_LEFT);
  lbllayout->setFont(mainFont);
  combolayout=new FXComboBox(controls,15,5,this,ID_LAYOUT,COMBOBOX_INSERT_LAST|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP);
  for(int i=0; i<20; i++){  combolayout->appendItem(strlayout[i]);         }
  combolayout->setCurrentItem(0);

  //Frame
  FXLabel *lblframe=new FXLabel(controls,"&Frame Type:",NULL,LAYOUT_LEFT|JUSTIFY_LEFT);
  lblframe->setFont(mainFont);
  comboframe=new FXComboBox(controls,15,5,this,ID_FRAME,COMBOBOX_INSERT_LAST|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP);
  for(int i=0; i<7; i++){  comboframe->appendItem(strframe[i]);         }
  comboframe->setCurrentItem(2);

  //Width
  FXLabel* lblWidth=new FXLabel(controls,"&Width:",NULL,LAYOUT_LEFT|JUSTIFY_LEFT);
  lblWidth->setFont(mainFont);
  spinw=new FXSpinner(controls,6,this,ID_WIDTH,SPIN_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP);
  spinw->setFont(mainFont);
  spinw->setRange(1,500);

  //Height
  FXLabel *lblHeight=new FXLabel(controls,"&Height:",NULL,LAYOUT_LEFT|JUSTIFY_LEFT);
  lblHeight->setFont(mainFont);
  spinh=new FXSpinner(controls,6,this,ID_HEIGHT,SPIN_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP);
  spinh->setFont(mainFont);
  spinh->setRange(1,400);

  //POS x
  FXLabel *lblPosX=new FXLabel(controls,"&X Pos:",NULL,LAYOUT_LEFT|JUSTIFY_LEFT);
  lblPosX->setFont(mainFont);
  spinPosX=new FXSpinner(controls,6,this,ID_POSX,SPIN_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP);
  spinPosX->setFont(mainFont);
  spinPosX->setRange(1,1000);
	
  //POS y
  FXLabel *lblPosY=new FXLabel(controls,"& Pos:",NULL,LAYOUT_LEFT|JUSTIFY_LEFT);
  lblPosY->setFont(mainFont);
  spinPosY=new FXSpinner(controls,6,this,ID_POSX,SPIN_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP);
  spinPosY->setFont(mainFont);
  spinPosY->setRange(1,1000);

  chkDeclare=new FXCheckButton(controls,"Declare in the class",this,ID_DECLARE,ICON_AFTER_TEXT|LAYOUT_NORMAL|FRAME_RAISED);
  chkDeclare->setFont(mainFont);
  chkColors=new FXCheckButton(controls,"Set Colors",this,ID_COLOR_DECLARE,ICON_AFTER_TEXT|LAYOUT_NORMAL|FRAME_RAISED);
  chkColors->setFont(mainFont);	

  // The sample
  sample=new FXArrowButton(mtxSamples,
                      NULL,0,
                      FRAME_RAISED|FRAME_THICK|LAYOUT_CENTER_X|LAYOUT_CENTER_Y|LAYOUT_FIX_WIDTH|LAYOUT_FIX_HEIGHT|ARROW_UP,
                      1,1,50,50);
  BaseColor=sample->getBaseColor();
  ShadowColor=sample->getShadowColor();
  HiliteColor=sample->getHiliteColor();
  BorderColor=sample->getBorderColor();
  BackColor=sample->getBackColor();
  spinw->setValue(sample->getWidth());
  spinh->setValue(sample->getHeight());
  sample->hide();

  btnOK=new FXButton(buttons,"Create\tCreate commands and\ncopy them into code window",NULL,this,ID_RESULTS,ICON_ABOVE_TEXT|JUSTIFY_NORMAL|LAYOUT_BOTTOM|LAYOUT_RIGHT|FRAME_RAISED,50,55,52,52);
  btnCancel=new FXButton(buttons,"Close\tCancel Dialog",NULL,this,FXDialogBox::ID_CANCEL,ICON_ABOVE_TEXT|JUSTIFY_NORMAL|LAYOUT_BOTTOM|LAYOUT_RIGHT|FRAME_RAISED,10,15,52,52);

}

ArrowDialog::~ArrowDialog(){}

long ArrowDialog::onCmdName(FXObject*,FXSelector,void*)
{
	sample->show();
	return 1;
}

long ArrowDialog::onCmdArrowDir(FXObject*,FXSelector,void*)
{
	FXuint style=sample->getArrowStyle();
	style=arrowdirection->getCurrentItem();
	switch (style)
	{
		case 0:	style|=ARROW_UP; break;
		case 1:	style|=ARROW_DOWN; break;
		case 2:	style|=ARROW_LEFT; break;
		case 3:	style|=ARROW_RIGHT; break;
	}
	sample->setArrowStyle(style);
	return 1;
}


long ArrowDialog::onCmdFrame(FXObject*,FXSelector,void*)
{
	FXuint style=sample->getFrameStyle();
	style=comboframe->getCurrentItem();
	switch (style)
	{
		case 0:	style|=FRAME_NONE; break;
		case 1:	style|=FRAME_NONE; break;
		case 2:	style|=FRAME_RAISED; break;
		case 3:	style|=FRAME_THICK; break;
		case 4:	style|=FRAME_GROOVE; break;
		case 5:	style|=FRAME_RIDGE; break;
		case 6:	style|=FRAME_LINE; break;
	}
	sample->setFrameStyle(style);
	return 1;
}

long ArrowDialog::onCmdAlign(FXObject*,FXSelector,void*)
{
	FXuint style=sample->getJustify();
	style=comboalign->getCurrentItem();
	switch (style)
	{
		case 0:
			style&=~JUSTIFY_LEFT;
			style|=JUSTIFY_NORMAL;break;
		case 1:
			style&=~JUSTIFY_HZ_APART; break;
		case 2:
			style&=~JUSTIFY_HZ_APART;
			style|=JUSTIFY_LEFT;	break;
		case 3:
			style&=~JUSTIFY_HZ_APART;
			style|=JUSTIFY_RIGHT;  	break;
		case 4:
			style|=JUSTIFY_HZ_APART; break;
		case 5:
			style&=~JUSTIFY_VT_APART; break;
		case 6:
			style&=~JUSTIFY_VT_APART;
			style|=JUSTIFY_TOP;	break;
		case 7:
			style&=~JUSTIFY_VT_APART;
			style|=JUSTIFY_BOTTOM;break;
	}
	sample->setJustify(style);
	return 1;
}

long ArrowDialog::onCmdLayout(FXObject*,FXSelector,void*)
{
               FXuint style=sample->getLayoutHints();
	style=combolayout->getCurrentItem();
	switch (style)
	{
		case 0:	style|=LAYOUT_NORMAL; break;
		case 1:	style|=LAYOUT_SIDE_TOP; break;
		case 2:	style|=LAYOUT_SIDE_BOTTOM; break;
		case 3:	style|=LAYOUT_SIDE_LEFT; break;
		case 4:	style|=LAYOUT_SIDE_RIGHT; break;
		case 5:	style|=LAYOUT_FILL_COLUMN; break;
		case 6:	style|=LAYOUT_FILL_ROW; break;
		case 7:	style|=LAYOUT_LEFT; break;
		case 8:	style|=LAYOUT_RIGHT; break;
		case 9:	style|=LAYOUT_CENTER_X; break;
		case 10:	style|=LAYOUT_FIX_X; break;
		case 11:	style|=LAYOUT_TOP; break;
		case 12:	style|=LAYOUT_BOTTOM; break;
		case 13:	style|=LAYOUT_CENTER_Y; break;
		case 14:	style|=LAYOUT_FIX_Y; break;
		case 15:	style|=LAYOUT_FIX_WIDTH; break;
		case 16:	style|=LAYOUT_FIX_HEIGHT; break;
		case 17:	style|=LAYOUT_MIN_WIDTH; break;
		case 18:	style|=LAYOUT_MIN_HEIGHT; break;
		case 19:	style|=LAYOUT_FILL_X; break;
	}
	sample->setLayoutHints(style);
	 return 1;
}

long ArrowDialog::onCmdTarget(FXObject*,FXSelector,void*)
{
	if (txtTarget->getText()=="") txtTarget->setText("NULL");
	return 1;
}

long ArrowDialog::onCmdSelector(FXObject*,FXSelector,void*)
{
	if (txtSelector->getText()=="") txtSelector->setText("0");
	return 1;
}

long ArrowDialog::onCmdWidth(FXObject*,FXSelector,void*)
{
   sample->setWidth(spinw->getValue());
   sample->update();
   return 1;
}

long ArrowDialog::onCmdHeight(FXObject*,FXSelector,void*)
{
	sample->setHeight(spinh->getValue());
	sample->update();
	return 1;
}

long ArrowDialog::onCmdPosX(FXObject*,FXSelector,void*)
{
	sample->setX(spinPosX->getValue());
	return 1;
}

long ArrowDialog::onCmdPosY(FXObject*,FXSelector,void*)
{
	sample->setY(spinh->getValue());
	return 1;
}

long ArrowDialog::onCmdArrowColor(FXObject*,FXSelector,void*)
{
	colordlg=new FXColorDialog(this,"Select Color",DECOR_BORDER|DECOR_TITLE);
	colordlg->FXDialogBox::execute();
	ArrowColor=colordlg->getRGBA();
	sample->setArrowColor(ArrowColor);
	return 1;
}

long ArrowDialog::onCmdColorDeclare(FXObject*,FXSelector,void*)
{
	return 1;
}

long ArrowDialog::onCmdDeclare(FXObject*,FXSelector,void*)
{
	return 1;
}

long ArrowDialog::onCmdBaseColor(FXObject*,FXSelector,void*)
{
	colordlg=new FXColorDialog(this,"Select Color",DECOR_BORDER|DECOR_TITLE);
	colordlg->FXDialogBox::execute();
	BaseColor=colordlg->getRGBA();
	sample->setBaseColor(BaseColor);
	return 1;
}

long ArrowDialog::onCmdBorderColor(FXObject*,FXSelector,void*)
{
	colordlg=new FXColorDialog(this,"Select Color",DECOR_BORDER|DECOR_TITLE);
	colordlg->FXDialogBox::execute();
	BorderColor=colordlg->getRGBA();
	sample->setBorderColor(BorderColor);
	return 1;
}

long ArrowDialog::onCmdHiliteColor(FXObject*,FXSelector,void*)
{
	colordlg=new FXColorDialog(this,"Select Color",DECOR_BORDER|DECOR_TITLE);
	colordlg->FXDialogBox::execute();
	HiliteColor=colordlg->getRGBA();
	sample->setHiliteColor(HiliteColor);
	return 1;
}

long ArrowDialog::onCmdShadowColor(FXObject*,FXSelector,void*)
{
	colordlg=new FXColorDialog(this,"Select Color",DECOR_BORDER|DECOR_TITLE);
	colordlg->FXDialogBox::execute();
	ShadowColor=colordlg->getRGBA();
	sample->setShadowColor(ShadowColor);
	return 1;
}

long ArrowDialog::onCmdBackColor(FXObject*,FXSelector,void*)
{	
	colordlg=new FXColorDialog(this,"Select Color",DECOR_BORDER|DECOR_TITLE);
	colordlg->FXDialogBox::execute();
	BackColor=colordlg->getRGBA();
	sample->setBackColor(BackColor);
	return 1;
}

long ArrowDialog::onCmdResults(FXObject*,FXSelector,void*)
{
	FXString Resultstxt;
              FXString strFont;
              FXString strItems;
	FXString*	SumRes;
	FXString TipStr;
	FXString TotalA;

	FXString ObjName;
	FXString ObjOwner;
	FXString ObjText;
	FXString ObjCols;
	FXString ObjTarget;
	FXString ObjSelector;
	FXString ObjTip;
	FXString ObjIcon;
	FXString ObjX;     FXString ObjY;
	FXString ObjW;    FXString ObjH;
              FXString ObjFont;
              FXString ArrowColorStr;	FXString BackColorStr;
	FXString ShadowColorStr;	FXString BorderColorStr;
	FXString BaseColorStr;    	FXString HiliteColorStr;
	FXString TextColorStr;     	FXString ObjOpts;
	FXString DeclareStr;	FXString newObjectStr;

	DeclareStr="FXArrowButton* ";
	newObjectStr="=new FXArrowButton(";
	ObjName=txtName->getText();
 	ObjOwner=txtOwner->getText()+",";
	ObjTarget=txtTarget->getText()+",";
	ObjSelector=txtSelector->getText()+",";
	ObjOpts=arrowdirection->getText()+"|"+comboalign->getText()+"|"+combolayout->getText()+"|"+comboframe->getText()+",";
	ObjX=FXStringVal(spinPosX->getValue(),10)+",";
	ObjY=FXStringVal(spinPosY->getValue(),10)+",";
	ObjW=FXStringVal(spinw->getValue(),10)+",";
	ObjH=FXStringVal(spinh->getValue(),10);
	ObjFont="";

	if ((chkDeclare->getCheck())==TRUE) DeclareStr="";
	if ((chkColors->getCheck())==TRUE)
	{
	BackColorStr=ObjName+"->setBackColor(FXRGBA("+FXStringVal(FXREDVAL(BackColor))+","+
		FXStringVal(FXGREENVAL(BackColor))+","+FXStringVal(FXBLUEVAL(BackColor))+","+
		FXStringVal(FXALPHAVAL(BackColor))+"));\n";
	BaseColorStr=ObjName+"->setBaseColor(FXRGBA("+FXStringVal(FXREDVAL(BaseColor))+","+
		FXStringVal(FXGREENVAL(BaseColor))+","+FXStringVal(FXBLUEVAL(BaseColor))+","+
		FXStringVal(FXALPHAVAL(BaseColor))+"));\n";
	ShadowColorStr=ObjName+"->setShadowColor(FXRGBA("+FXStringVal(FXREDVAL(ShadowColor))+","+
		FXStringVal(FXGREENVAL(ShadowColor))+","+FXStringVal(FXBLUEVAL(ShadowColor))+","+
		FXStringVal(FXALPHAVAL(ShadowColor))+"));\n";
	BorderColorStr=ObjName+"->setBorderColor(FXRGBA("+FXStringVal(FXREDVAL(BorderColor))+","+
		FXStringVal(FXGREENVAL(BorderColor))+","+FXStringVal(FXBLUEVAL(BorderColor))+","+
		FXStringVal(FXALPHAVAL(BorderColor))+"));\n";
	HiliteColorStr=ObjName+"->setHiliteColor(FXRGBA("+FXStringVal(FXREDVAL(HiliteColor))+","+
		FXStringVal(FXGREENVAL(HiliteColor))+","+FXStringVal(FXBLUEVAL(HiliteColor))+","+
		FXStringVal(FXALPHAVAL(HiliteColor))+"));\n";
	ArrowColorStr=ObjName+"->setHiliteColor(FXRGBA("+FXStringVal(FXREDVAL(ArrowColor))+","+
		FXStringVal(FXGREENVAL(ArrowColor))+","+FXStringVal(FXBLUEVAL(ArrowColor))+","+
		FXStringVal(FXALPHAVAL(ArrowColor))+"));\n";	
	TextColorStr=ObjName+"->setTextColor(FXRGBA("+FXStringVal(FXREDVAL(TextColor))+","+
		FXStringVal(FXGREENVAL(TextColor))+","+FXStringVal(FXBLUEVAL(TextColor))+","+
		FXStringVal(FXALPHAVAL(TextColor))+"));\n";
	}
	else
	{
		ArrowColorStr="";
		BackColorStr="";
		BaseColorStr="";
		ShadowColorStr="";
		BorderColorStr="";
		HiliteColorStr="";
		TextColorStr="";
	}
	TotalA=DeclareStr+ObjName+newObjectStr+ObjOwner+ObjTarget+ObjSelector+ObjOpts+ObjX+ObjY+ObjW+ObjH+");\n"+
		ArrowColorStr+BackColorStr+ShadowColorStr+BorderColorStr+BaseColorStr+HiliteColorStr;
	SumRes=&TotalA;
	editor->insertText(editor->getCursorPos(),SumRes->text(),SumRes->size()-1, FALSE);	
	sample->hide();
	return 1;
}
